/**
* @license
* Copyright (C) 2017-2018 "IoT.bzh"
* Author Sebastien Douheret <sebastien@iot.bzh>
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*   http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

import { RouterModule, Routes } from '@angular/router';
import { NgModule } from '@angular/core';

import { PagesComponent } from './pages.component';
import { DashboardComponent } from './dashboard/dashboard.component';
import { ProjectsComponent } from './projects/projects.component';
import { SdksComponent } from './sdks/sdks.component';
import { SdkManagementComponent } from './sdks/sdk-management/sdk-management.component';
import { TargetsComponent } from './targets/targets.component';
import { TerminalsComponent } from './targets/terminals/terminals.component';
import { BuildComponent } from './build/build.component';
import { SupervisionComponent } from './supervision/supervision.component';
import { SupervisionConfigComponent } from './supervision/supervision-config.component';

const routes: Routes = [{
  path: '',
  component: PagesComponent,
  children: [{
    path: 'dashboard',
    component: DashboardComponent,
  }, {
    path: 'projects',
    component: ProjectsComponent,
  }, {
    path: 'sdks',
    component: SdksComponent,
  }, {
    path: 'sdks/management',
    component: SdkManagementComponent,
  }, {
    path: 'build',
    component: BuildComponent,
  }, {
    path: 'targets/list',
    component: TargetsComponent,
  }, {
    path: 'targets/term',
    component: TerminalsComponent,
  }, {
    path: 'supervision/config',
    component: SupervisionConfigComponent,
  }, {
    path: 'supervision/graph',
    component: SupervisionComponent,
  }, {
    path: 'config',
    loadChildren: './config/config.module#ConfigModule',
  },
  {
    path: '',
    redirectTo: 'dashboard',
    pathMatch: 'full',
  }],
}];

@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class PagesRoutingModule {
}
